@@ -256,6 +256,7 @@ class NnMixer:
         get the actual mixer model
         :return: self.net
         """
+        self.optimizer.zero_grad()
         return copy.deepcopy(self.net)
 
     def update_model(self, model):
@@ -427,6 +428,7 @@ class NnMixer:
                 if awareness_loss is not None:
                     awareness_loss.backward(retain_graph=True)
 
+                running_loss += loss.item()
                 loss.backward()
 
                 # @NOTE: Decrease 900 if you want to plot gradients more often, I find it's too expensive to do so
